@@ -171,13 +171,16 @@ void KmaModel::AlignAndAssignObservations(arma::mat &warpingParameters,
         m_WarpingPointer
       );
 
-      workingParameterValues.row(i) = startingParameters;
+      if (numberOfParameters > 0)
+        workingParameterValues.row(i) = startingParameters;
     }
 
     observationDistances(j) = workingObservationDistances.min();
     unsigned int assignedTemplateIndex = arma::index_min(workingObservationDistances);
     observationMemberships(j) = clusterIndices(assignedTemplateIndex);
-    warpingParameters.row(j) = workingParameterValues.row(assignedTemplateIndex);
+
+    if (numberOfParameters > 0)
+      warpingParameters.row(j) = workingParameterValues.row(assignedTemplateIndex);
   }
 }
 
@@ -192,6 +195,10 @@ void KmaModel::RunAdaptiveFenceAlgorithm(arma::mat &warpingParameters,
                                          const double penalizationStep)
 {
   unsigned int numberOfParameters = warpingParameters.n_cols;
+
+  if (numberOfParameters == 0)
+    return;
+
   arma::vec quantileOrders = { 0.25, 0.75 };
   arma::mat quantileValues;
   arma::mat fenceValues;
@@ -298,7 +305,9 @@ void KmaModel::UpdateTemplates(const unsigned int numberOfIterations,
       {
         unsigned int observationIndex = selectedObservations(j);
         warpedGrids.row(observationIndex) = m_WarpingPointer->ApplyWarping(warpedGrids.row(observationIndex), warpingParameters);
-        warpingParametersContainer.slice(2 * (numberOfIterations - 1) + 1).row(observationIndex) = warpingParameters;
+
+        if (warpingParameters.size() > 0)
+          warpingParametersContainer.slice(2 * (numberOfIterations - 1) + 1).row(observationIndex) = warpingParameters;
       }
     }
 
@@ -338,7 +347,9 @@ void KmaModel::UpdateTemplates(const unsigned int numberOfIterations,
       {
         unsigned int observationIndex = selectedObservations(j);
         warpedGrids.row(observationIndex) = m_WarpingPointer->ApplyWarping(warpedGrids.row(observationIndex), warpingParameters);
-        warpingParametersContainer.slice(2 * (numberOfIterations - 1) + 1).row(observationIndex) = warpingParameters;
+
+        if (warpingParameters.size() > 0)
+          warpingParametersContainer.slice(2 * (numberOfIterations - 1) + 1).row(observationIndex) = warpingParameters;
       }
     }
 
